@@ -48,20 +48,12 @@ enum Operation {
 }
 
 /// A builder for for setting up a `Client`. Created using `Client::builder`
+#[derive(Default)]
 pub struct ClientBuilder {
     http2_prior_knowledge: bool,
     danger_accept_invalid_certs: bool,
 }
 
-impl Default for ClientBuilder {
-    fn default() -> Self {
-        Self {
-            http2_prior_knowledge: false,
-            danger_accept_invalid_certs: false,
-        }
-    }
-}
-
 impl ClientBuilder {
     /// Controls whether the client assumes HTTP/2 or attempts to negotiate it. Defaults to false.
     pub fn http2_prior_knowledge(mut self, http2_prior_knowledge: bool) -> Self {
@@ -617,6 +609,10 @@ async fn unwrap_status(
         (StatusCode::CONFLICT, Endpoint::Invoice) => Err(ClientError::InvoiceAlreadyExists),
         (StatusCode::CONFLICT, Endpoint::Parcel) => Err(ClientError::ParcelAlreadyExists),
         (StatusCode::UNAUTHORIZED, _) => Err(ClientError::Unauthorized),
+        (StatusCode::BAD_REQUEST, _) => Err(ClientError::ServerError(Some(
+            "The request could not be handled by the server. Verify your Bindle server URL"
+                .to_owned(),
+        ))),
         // You can't range match on u16 so we use a guard
         (_, _) if resp.status().is_server_error() => {
             Err(ClientError::ServerError(parse_error_from_body(resp).await))
